function callbackGO;
%% ===========================================================================
% calbackGO - Callback to run experiment
% 
% Example(s):
%	uicontrol('string','GO','Position', [310 fheight-uiheight+10 60 20],...
%       	  'callback','result=callbackGO;')
% Algorithmic details:
%
% Reference:
%    
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1998-2000
% by Telia Research AB, Lulea, Sweden;                    All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: callbackGO.m,v 1.1 2000/03/30 13:02:35 tono Exp $
%% ===========================================================================
% Change History
%      1999-02-04 (DaB)  Created
%      1999-02-04 (ToNo) Modified header and changed name to callbackGO
%      2000-03-13 (ToNo) Set up effiencyLoss for ADSL
%% ===========================================================================
global ex;
global gui;

% Set up a the list of analysed modems (modemlist)
if gui.testADSL,
   ex.param.modemlist=unique([ex.param.modemlist; 'ADSL'],'rows');
else
   ex.param.modemlist=setdiff(ex.param.modemlist,'ADSL','rows');
end;

if gui.testVDSL,
   ex.param.modemlist=unique([ex.param.modemlist; 'VDSL'],'rows');
else
   ex.param.modemlist=setdiff(ex.param.modemlist,'VDSL','rows');
end;

% Define what VDSL plan to use
gui.xDSL=getList(ex.param.xDSLlist,'VDSL');
gui.xDSL.used=gui.vdslDuplex;
ex.param.xDSLlist=setList(ex.param.xDSLlist,'VDSL',gui.xDSL);

ex.tfplist=setList(ex.tfplist,gui.vdslDuplex,gui.tfplan);
ex.lclist=setList(ex.lclist,gui.tfplan.lcname,gui.lc);

% Set up effiencyLoss for ADSL using gui.efficiencyLoss.ADSL
if gui.testADSL,
    adslact=getList(ex.param.xDSLlist,'ADSL');
    if length(adslact)>0,
	atfp=getList(ex.tfplist,adslact.used);
	alc=getList(ex.lclist,atfp.lcname);
	alc.param.efficiencyLoss = gui.efficiencyLoss.ADSL;
	ex.lclist=setList(ex.lclist,alc.name,alc);
    end;
end;

% Run experiment
set(gui.setupfig,'Pointer','watch');
result = evalExperiment;
set(gui.setupfig,'Pointer','arrow');

% Show results
uiResults(ex,result);
