function gui = setupGUI;
%% ===========================================================================
%setupGUI - Sets up the experiment description structure for
% a certain FSAN duplex experiment.

% Returns:      gui		Structure describing the experiment parameters
%
% Example(s):
%   gui = setupGUI; 
%
% Algorithmic details:
%   Fill in the ex.param structure according to default parameters and input
%   parameters.
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1999 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: setupGUI.m,v 1.1 2000/03/30 13:02:35 tono Exp $
%% ===========================================================================
% Change History
%      1999-10-02 (DaB) Created
%% ===========================================================================

%% ===========================================================================

% Some simulation default values
gui.ttlist            = [];		% Traffic & Topology
gui.testVDSL	       = 1;       	% Tells if VDSL is evaluated
gui.testADSL	       = 0;       	% Tells if ADSL is evaluate
gui.effiencyLoss.VDSL = 0.1;
gui.effiencyLoss.ADSL = 0.1;
gui.SNRMax            = 60;
gui.shannonGap        = 9.8;
gui.PBO.param         = 0;
gui.HAM               = 1;



% Set default font and size
set(0,'DefaultAxesFontName','times')
set(0,'DefaultTextFontName','times')
if strcmp(computer,'PCWIN'),
    gui.fontBaseSize=9;
else
    gui.fontBaseSize=11;
end;
set(0,'DefaultAxesFontSize',gui.fontBaseSize+1)
set(0,'DefaultTextFontSize',gui.fontBaseSize)

set(0,'Units','pixels');		% Get screen size
gui.screensize=get(0,'ScreenSize');		
gui.swidth=gui.screensize(3);
gui.sheight=gui.screensize(4);

gui.bdwidth=7;				% Define window layout on screen
gui.fwidth=gui.swidth/2-gui.bdwidth*5; 	% Make space for two windows side by side
gui.fwidth=max(gui.fwidth,550);
gui.fwidth=min(gui.fwidth,gui.swidth);
gui.fheight=max(gui.fwidth,650);
gui.fheight=min(gui.fheight,gui.sheight);
gui.bottom=gui.sheight-gui.fheight-100;

gui.setupfig=figure(1);			% Define the main setup window
clf;
set(gcf,'Pointer','arrow');
set(gui.setupfig,'NumberTitle','off','Name','FSAN xDSL Simulation Tool', ...
     'Position', [gui.bdwidth gui.bottom gui.fwidth gui.fheight],'Tag','SetupFig');
set(gui.setupfig,'PaperPositionMode','auto');  

