% The xDSL simulation tool
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions to set up an experiment
%
%  setupParam           Routine to set up the parameter part of the ex struct.
%  setupLClist          Set up theoretical line code dependent structures
%
%  calcPSD              Generates a PSD mask from a PSD description
%  setupPSDplan         Generate a PSD description from a simple list
%  makeUFplan		Generate a tfplan from a freq. grid and 'ud' directions
%  planConvertion       Convert a frequency grid into a plan based on center fq and bw
%
%  plotTFplan           Plots the PSD mask for a certain TF plan
%  plotTTstructure      Plots the TT structure
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for the evaluation of an experiment
%
%  evalExperiment       The main evaluation routine
%  checkEx              Check experiment description in the global structure ex
%  evalNoise  		Calc noise in LT & NT nodes between start and stop node
%  evalPBO  		Calculates power back-off (PBO) for up and downstream
%  getMinFreqaxis  	Finds minimal set of frequencies for frequency axis
%  getDM                Finds index in traffic that match modem types (ADSL/VDSL)
%  addFSAN              Adds noise according to the FSAN combination method
%  setTT                Modify a tt struct by replacing generic names with specific ones
%  sqrcPSD		Generate a square root raised cosine mask
%
%  getAtt               Get the attenuation (instertion loss) in a topology
%  getABCD              Get the ABCD parameters in a topology   
%  getTwoPortModel      Get the two port model [Z0,gamma] for cable 'name' 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Post processing and results
%
%  calcFSANresult       Calculate all disturbed modem bitrates (linecode dep.)
%  calcResultTheo  	Calculate resulting theoretical bit rates
%  calcResultDMT  	Calculate resulting bit rates for DMT
%  calcResultSCM  	Calculate resulting bit rates for SCM
%
%  plotResult  		Plot a result plot
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% GUI suport routines
%
%  getNoiseModels       Gets all available noise models for this tool
%  getPBOmethods        Gets all available PBO methods for this tool
%  getMaxVDSLlength     Get the maximum VDSL modem length
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% List handling routines
%
%  getList		Get an object from a list based on the object name
%  getNameList		Get list of names of the objects in a list
%  insertList		Insert an object into a list
%  setList		Set a named object in a list to a new value (object)
%
% Other help functions
%  findStrIndex         Find string (index) in array of strings
%
% Misc
%  Content  		This file
%  fsansimuVersion	Returns current simulator version

%% ===========================================================================
% Copyright (C):
%       1998-2000 by Telia Research AB, Lulea, Sweden;
%       2000 by FTW, Wien, Austria;
%                                                         All rights reserved.
% Description   : The contents of the main xDSL simulation tool directory
%
% File          : Content.m
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: Contents.m,v 1.6 2000/09/17 14:01:48 tono Exp $
%% ===========================================================================
% Change History
%      1998-11-13 (ToNo) Created
%      1998-12-18 (ToNo) Added the new files
%      1998-12-21 (ToNo) Added even more new files
%      1999-01-11 (ToNo) Updated before release
%      1999-01-18 (ToNo) Added getMaxVDSLlength
%      1999-03-25 (ToNo) Updated before release
%      1999-11-19 (ToNo) Updated before release version 2
%      2000-03-13 (ToNo) Some minor editing
%      2000-03-14 (ToNo) Restructured into pre step, eval, and a post step
%      2000-04-04 (DaB)  Removed calcRate
%      2000-09-17 (ToNo) Removed some unused functions and added some new ones
%% ===========================================================================
