function models = getNoiseModels();
%% ===========================================================================
%getNoiseModels - Gets all available noise models for FSAN duplex experiments.
%
% Returns:      models	List of (predefined) noise models that can be used
%
% Example(s):
%   mod = getNoiseModels; returns an array of strings containing available 
%   model names
%
% Algorithmic details:
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1999-2000
% by Telia Research AB, Lulea, Sweden;                    All rights reserved. 
%
% Project       : FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: getNoiseModels.m,v 1.8 2000/03/13 16:49:42 tono Exp $
%% ===========================================================================
% Change History
%      1999-01-05 (ToNo) Created
%      2000-03-13 (ToNo) Now dynamicly calculates the possible noise models
%% ===========================================================================
global ex;

% Note this assumes noise models starts with 'Model'
cells(1)={'Calculate'};
cellno=2;
for i=1:length(ex.tfplist),
    if (strncmp(ex.tfplist(i).name, 'Model', 5)) 
	cells(cellno)={ex.tfplist(i).name};
	cellno=cellno+1;
    end;
end
models=str2mat(char(cells));                                                 
