function lclist = setupLClist();
%% ===========================================================================
%setupLClist - Define a default theoretical line code model.
%
% Returns:      lclist		A list of structures describing time and
%                               frequency plans
%
% Example(s):
%    lclist = setupLClist; 
%
% Algorithmic details:
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1998-2000 by Telia Research AB, Lulea, Sweden;                
%       2000 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: setupLClist.m,v 1.13 2000/05/02 13:05:42 tono Exp $
%% ===========================================================================
% Change History
%      1999-10-01 (DaB) Created
%      2000-01-12 (DaB)  lc function changed
%      2000-01-12 (DaB) xtalk_margin added and Px
%      2000-04-04 (DaB) signal_margin added
%% ===========================================================================

% Default Parameter values
def_param.signal_margin  = 0;
def_param.xtalk_margin   = 6;
def_param.refSNR         = 9.8;
def_param.codingGain     = 3.5;
def_param.SNRloss        = 0;


def_param.efficiencyLoss = 0.1;
def_param.SNRMax         = 60;
def_param.Px             = 11.5;

% Default VDSL parameters
vdsl_param = def_param;

% VDSL Theoretical params 
tmp_lc.name	         = 'VDSL-theo';
tmp_lc.param	         = def_param;
tmp_lc.calcRate          = 'calcResultTheo';
tmp_lc.lcPrint 	         = 'lcPrintTheo';

lclist(1) = tmp_lc;
