function tfplist = itu_tfplistsMISC(tfplist);
%% ===========================================================================
%itu_tfplistsMISC(tfplist) - Sets up the tfplan for ITU alien systems
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = itu_tfplistsMISC(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'PNT');      Get the PNT mask
%
%   ex.tfplist = itu_tfplistsMISC([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'PNT-3dB');  Get the PNT mask (-3dB)
%
% Reference:
%    ITU SG15 Question 4/15 NT-G12
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1999 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: itu_tfplistsMISC.m,v 1.4 2000/05/26 13:17:46 uvan Exp $
%% ===========================================================================
% Change History
%      1999-11-05 (ToNo) Created
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD and removed "global ex"
%      2000-04-11 (DaB)  added sync
%      2000-05-26 (UvAn) Added possibillities to fix the bitrate 
%% ===========================================================================

%% ===========================================================================
% Template, order important!

% Default values
def_tfplan.name                  = 'N/A';
def_tfplan.PSD.downstream        = 'N/A';
def_tfplan.PSD.upstream          = 'N/A';
def_tfplan.PSD.active.upstream   = [1 30e6];
def_tfplan.PSD.active.downstream = [1 30e6];
def_tfplan.PSD.PBO.method        = 'None';	% Power back-off method (-=not applicable)
def_tfplan.PSD.PBO.param.len     = 1500;		% PBO parameter {length(m)}
def_tfplan.PSD.PBO.param.freq    = 2e6;	
def_tfplan.PSD.PBO.param.maxlen  = 1500;
def_tfplan.PSD.HAM.active        = 0;
def_tfplan.timeDivision.up       = 1; % Time used in up resp. down lin
def_tfplan.timeDivision.down     = 1;
def_tfplan.timeDivision.sync     = 1;
def_tfplan.fixBitrate.name       = 'None';  % Fixed bitrate method
def_tfplan.fixBitrate.active     = 0;       % 0=inactive, 1=active
def_tfplan.fixBitrate.param      = 'N/A';   
def_tfplan.lcname                = 'N/A';

%% ===========================================================================
% TFPlan  definitions starting
% -------------------------------

% ITU g.pnt
tmp_tfplan=def_tfplan;
tmp_tfplan.name='PNT'; 
tmp_tfplan.PSD.downstream='calcPSD([ 2.7e6 -140 3.5e6 -93.5 4.5e6 -73.5 7e6 -73.5 7e6 -83.5 7.3e6 -83.5 7.3e6 -73.5 9.5e6 -73.5 10e6 -83.5 11.5e6 -108.5 12e6 -123.5 12.5e6 -135 30e6 -135 30e6 -140],''Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
def_tfplan.PSD.active.upstream   = [2.7e6 12.5e6];
def_tfplan.PSD.active.downstream = [2.7e6 12.5e6];
tfplist=insertList(tfplist,tmp_tfplan);

% ITU g.pnt (-3dB)
tmp_tfplan=def_tfplan;
tmp_tfplan.name='PNT-3dB'; 
tmp_tfplan.PSD.downstream='calcPSD([ 2.7e6 -140 3.5e6 -96.5 4.5e6 -76.5 7e6 -76.5 7e6 -86.5 7.3e6 -86.5 7.3e6 -76.5 9.5e6 -76.5 10e6 -86.5 11.5e6 -111.5 12e6 -126.5 12.5e6 -138 30e6 -138 30e6 -140],''Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
def_tfplan.PSD.active.upstream   = [2.7e6 12.5e6];
def_tfplan.PSD.active.downstream = [2.7e6 12.5e6];
tfplist=insertList(tfplist,tmp_tfplan);
