function lc = lcDefVDSLDMT;
%% ===========================================================================
%lcDefDMT - Sets up the lincode description structure for DMT
% Returns:      lc	The linecode structure
%
% Example(s):
%
% Algorithmic details:
%   Fill in the modemdef structure according to default parameters and input
%   parameters.
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1999 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: lcDefVDSLDMT.m,v 1.3 2000/07/20 13:40:01 tono Exp $
%% ===========================================================================
% Change History
%      1999-10-11 (ToNo) Created
%      2000-01-12 (Dab)  lc function changed
%      2000-04-04 (Dab)  added signal margin
%% ===========================================================================

lc.name           	= 'VDSL-DMT';

% Default Parameter values

% get the margin
lc.param.signal_margin  = 0;
lc.param.xtalk_margin   = 6;
lc.param.refSNR         = 9.8;
lc.param.codingGain     = 3.5;
lc.param.SNRloss        = 0;
lc.param.Px             = 11.5;

% Param digital
lc.param.dmt.df		   = 4.3125e3;   % carrier spacing 
lc.param.dmt.carriers   = 4096;       % number of carriers used
lc.param.fs             = lc.param.dmt.df*lc.param.dmt.carriers*2; % Sampling frequency
lc.param.dmt.cp         = 640;        % cyclic prefix value (actually all extensions)
lc.param.dmt.cs         = 0;          % cyclic suffix value
lc.param.dmt.my         = 0;          % sampels used for windowing
lc.param.dmt.beta       = 0;          % sampels used for pulse shaping

lc.param.constellation  = (2:11);     % bit constellation supported
lc.param.SNRMax         = 46;         % 11*3 + (9.8+6-3.5)=45.3

lc.param.efficiencyLoss = 1-2*lc.param.dmt.carriers./ ...
    (lc.param.dmt.cp+lc.param.dmt.cs+lc.param.dmt.my+lc.param.dmt.beta+lc.param.dmt.carriers*2);
lc.param.alpha           = 0;

lc.calcRate 		= 'calcResultDMT';
lc.lcPrint 		= 'lcPrintDMT';
