function lc = lcDefSCM;
%% ===========================================================================
%lcDefSCM - Sets up the lincode description structure for SCM
% Returns:      lc	The linecode structure
%
% Example(s):
%
% Algorithmic details:
%   Fill in the modemdef structure according to default parameters and input
%   parameters.
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1999 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: lcDefVDSLSCM.m,v 1.5 2000/05/10 11:09:49 uvan Exp $
%% ===========================================================================
% Change History
%      1999-10-11 (ToNo) Created
%      2000-01-12 (Dab)  lc function changed
%      2000-04-04 (Dab)  added signal margin
%      2000-04-05 (UvAn) "global ex" removed
%      2000-05-09 (UvAn) Removed frequency definitions 
%% ===========================================================================

lc.name           	= 'VDSL-SCM';

% get the margin 
lc.param.signal_margin  = 0;
lc.param.xtalk_margin = 6;
lc.param.refSNR       = 9.8;
lc.param.codingGain   = 3.5;
lc.param.SNRloss      = 0;

% Default Parameter values
lc.param.efficiencyLoss = 0.0;
lc.param.SNRMax         = 45;
lc.param.Px             = 11.5;

lc.param.constellation   	= (2:8);		% bitconstellation supported
lc.param.efficiencyLoss  	= 0;

lc.param.alpha            	= 0.2;
lc.param.guardBand	      = 0.1;

lc.param.reqSNR          	= 10*log10(10.^((lc.param.refSNR-...
    lc.param.codingGain)/10).*(2.^(lc.param.constellation)-1)); %

lc.calcRate     = 'calcResultSCM';
lc.lcPrint 		 = 'lcPrintSCM';
