function P=modelPSD_HDSL(f)
%% ===========================================================================
% modelPSD_HDSL PSD mask for HDSL
%
% Parameter:    f	frequency axis
% Returns:      P	PSD mask (in mW)
%
% Example(s):
%   
% Algorithmic details:
%   
% Reference:
%    T1E1.4/99 -438R2
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2000 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : B1, FTW
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: modelPSD_HDSL.m,v 1.1 2000/07/12 09:13:06 tono Exp $
%% ===========================================================================
% Change History
%      2000-07-10 (ToNo) Created
%% ===========================================================================

Vp   = 2.7;     % V
R    = 135;     % Ohm
f0   = 392e3;   % Hz
f3dB = 196e3;   % Hz

P=(5/9)*(Vp*Vp/R)*(2/f0)*(sinc(f/f0)).^2./(1 + (f/f3dB).^8) * 1000; % mW

function y=sinc(x)
		
y=ones(size(x));
i=find(x);
y(i)=sin(pi*x(i))./(pi*x(i));
