function P=modelPSD_ISDN_PRA(f)
%% ===========================================================================
% modelPSD_ISDN_PRA - calculates PSD mask for DTAG ISDN_PRA (HDB3) model 
%
% Parameter:    f	frequency axis
% Returns:      P	PSD mask  (in mW)
%
% Example(s):
%   
% Algorithmic details:
%   
% Reference:
%    FSAN xDSL simulation tool manual
%    Model provided by DTAG (ref. Mathias Friese)
%    TD20 ETSI Villach 1999    
%    TD22 ETSI Edinburgh 1999    
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1998-2000 by Telia Research AB, Lulea, Sweden;                
%       2000 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FSAN duplex model
% Author(s)     : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: modelPSD_ISDN_PRA.m,v 1.2 2000/07/20 13:40:01 tono Exp $
%% ===========================================================================
% Change History
%      1999-02-09 (DaB)  Created
%      1999-03-01 (DaB)  Use Rob's model from TD20 ETSI Villach 1999
%      2000-07-12 (ToNo) Moved to xdsldefs and cleaned up comments
%% ===========================================================================

P0   = 12.4; % mW  = 10.92 dBm;  
Rs   = 130;   
f0   = 1.024.*1e6; 
f3dB = 1.024.*1e6; 
N    = 0.9;

P=2./f0.*(sinc(f./f0-1)).^2./(1 + (f/f3dB).^(2.*N)).*P0;

function y=sinc(x)
		
y=ones(size(x));
i=find(x);
y(i)=sin(pi*x(i))./(pi*x(i));
