function P=modelPSD_T1(f)
%% ===========================================================================
% modelPSD_T1 PSD mask for T1
%
% Parameter:    f	frequency axis
% Returns:      P	PSD mask (in mW)
%
% Example(s):
%   
% Algorithmic details:
%   
% Reference:
%    T1E1.4/99 -438R2
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2000 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : B1, FTW
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: modelPSD_T1.m,v 1.1 2000/07/12 09:13:06 tono Exp $
%% ===========================================================================
% Change History
%      2000-07-10 (ToNo) Created
%% ===========================================================================

Vp    = 3.6;    % V
R     = 100;    % Ohm
f0    = 1544e3; % Hz
fL3dB = 3e6;    % Hz
fH3dB = 40e3;   % Hz

P=(Vp*Vp/R)*(2/f0)*(sinc(f/f0)).^2.*(sin(pi*f/2/f0)).^2 ...
  ./(1 + (f/fL3dB).^6).*f.^2./(f.^2+fH3dB.^2) * 1000; % mW

function y=sinc(x)
		
y=ones(size(x));
i=find(x);
y(i)=sin(pi*x(i))./(pi*x(i));
